# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.1

import enum

import winrt.system
from winrt import _winrt_windows_security_authentication_onlineid

__all__ = [
    "CredentialPromptType",
    "OnlineIdSystemTicketStatus",
    "OnlineIdAuthenticator",
    "OnlineIdServiceTicket",
    "OnlineIdServiceTicketRequest",
    "OnlineIdSystemAuthenticator",
    "OnlineIdSystemAuthenticatorForUser",
    "OnlineIdSystemIdentity",
    "OnlineIdSystemTicketResult",
    "SignOutUserOperation",
    "UserAuthenticationOperation",
    "UserIdentity",
]

class CredentialPromptType(enum.IntEnum):
    PROMPT_IF_NEEDED = 0
    RETYPE_CREDENTIALS = 1
    DO_NOT_PROMPT = 2

class OnlineIdSystemTicketStatus(enum.IntEnum):
    SUCCESS = 0
    ERROR = 1
    SERVICE_CONNECTION_ERROR = 2

OnlineIdAuthenticator = _winrt_windows_security_authentication_onlineid.OnlineIdAuthenticator
OnlineIdServiceTicket = _winrt_windows_security_authentication_onlineid.OnlineIdServiceTicket
OnlineIdServiceTicketRequest = _winrt_windows_security_authentication_onlineid.OnlineIdServiceTicketRequest
OnlineIdSystemAuthenticator = _winrt_windows_security_authentication_onlineid.OnlineIdSystemAuthenticator
OnlineIdSystemAuthenticatorForUser = _winrt_windows_security_authentication_onlineid.OnlineIdSystemAuthenticatorForUser
OnlineIdSystemIdentity = _winrt_windows_security_authentication_onlineid.OnlineIdSystemIdentity
OnlineIdSystemTicketResult = _winrt_windows_security_authentication_onlineid.OnlineIdSystemTicketResult
SignOutUserOperation = _winrt_windows_security_authentication_onlineid.SignOutUserOperation
UserAuthenticationOperation = _winrt_windows_security_authentication_onlineid.UserAuthenticationOperation
UserIdentity = _winrt_windows_security_authentication_onlineid.UserIdentity
